{****************************************************}
{}
{	CSATWindow																									}
{}
{	Window class for use with the Sprite Animation Toolkit. The rationale is		}
{	that a single instance of this class contains the SAT Pane.								}
{}
{	This class takes care of the SATWindMoved calls, informing SAT that the		}
{	window containing its drawing area has moved.												}
{}
{****************************************************}


unit CSATWindow;

interface

	uses
		TCL, SATTCLIntf;

implementation


{****************************************************}
{}
{	ISATWindow																									}
{}
{	Initializes a SAT Window object.																	}
{}
{****************************************************}

	procedure CSATWindow.ISATWindow (WINDid: Integer;
									aFloating: Boolean;
									anEnclosure: CDesktop;
									aSupervisor: CDirector);

	begin { ISATWindow }
		IWindow(WINDid, aFloating, anEnclosure, aSupervisor);

		{ As long as this is nil, there is no SAT Pane. }
		itsSATPane := nil;
	end; { ISATWindow }


{****************************************************}
{}
{	SetSATPane																									}
{}
{	For completeness, reset our pointer to the SAT Pane.									}
{}
{****************************************************}

	procedure CSATWindow.Free;

	begin { Free }
		itsSATPane := nil;

		inherited Free;
	end; { Free }


{****************************************************}
{}
{	InstallSATPane																								}
{}
{	Call this to install the SAT Pane.																	}
{}
{****************************************************}

	procedure CSATWindow.InstallSATPane (aSATPane: CSATPane);

	begin { InstallSATPane }
		itsSATPane := aSATPane;
	end; { InstallSATPane }


{****************************************************}
{}
{	Drag																												}
{}
{	After dragging, call SAT.																				}
{}
{****************************************************}

	procedure CSATWindow.Drag (macEvent: EventRecord);

	begin { Drag }
		inherited Drag(macEvent);

		SATWindMoved;
	end; { Drag }


{****************************************************}
{}
{	Move																											}
{}
{	After moving, call SAT.																				}
{}
{****************************************************}

	procedure CSATWindow.Move (hGlobal, vGlobal: integer);

	begin { Move }
		inherited Move(hGlobal, vGlobal);

		SATWindMoved;
	end; { Move }


{****************************************************}
{}
{	MoveOffScreen																								}
{}
{	After moving offscreen, call SAT.																	}
{}
{****************************************************}

	procedure CSATWindow.MoveOffScreen;

	begin { Move }
		inherited MoveOffScreen;

		SATWindMoved;
	end; { Move }


end. { CSATWindow }